---
name: Bug report
about: Create a report (for github issue tracker) to correct failures
title: ''
labels: ''
assignees: ''
---
**Describe the bug**

Please provide a concise, clear description of the bug, as well as any available error logs.  Feel free to contact the Kokkos Slack `# build` channel for further discussion of your issue.

**Please include the following for a minimal reproducer**

1. Compilers (with versions)
2. Kokkos release or commit used (i.e., the sha1 number)
3. Platform, architecture and backend
4. CMake configure command
5. Output from CMake configure command
6. Minimum, complete code needed to reproduce the bug
7. Command line needed to reproduce the bug
8. `KokkosCore_config.h` header file (generated during the build)
9. Please provide any additional relevant error logs
